Class: Google::Apis::OsconfigV1beta::GoogleCloudOsconfigCommonV1mainOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1beta::GoogleCloudOsconfigCommonV1mainOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb
Overview
Represents the metadata of a generic long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudOsconfigCommonV1mainOperationMetadata
constructor
A new instance of GoogleCloudOsconfigCommonV1mainOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudOsconfigCommonV1mainOperationMetadata
Returns a new instance of GoogleCloudOsconfigCommonV1mainOperationMetadata.
761 762 763 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 761 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
725 726 727 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 725 def api_version @api_version end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
730 731 732 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 730 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
735 736 737 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 735 def end_time @end_time end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have successfully been cancelled have Operation.
error value with a google.rpc.Status.code of 1, corresponding to Code.
CANCELLED.
Corresponds to the JSON property requestedCancellation
743 744 745 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 743 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusMessage
749 750 751 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 749 def @status_message end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
754 755 756 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 754 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
759 760 761 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 759 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
766 767 768 769 770 771 772 773 774 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 766 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |