Class: Google::Apis::OsconfigV1beta::GoogleCloudOsconfigV2OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudOsconfigV2OperationMetadata

Returns a new instance of GoogleCloudOsconfigV2OperationMetadata.



866
867
868
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 866

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


830
831
832
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 830

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


835
836
837
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 835

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


840
841
842
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 840

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have been cancelled successfully have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


848
849
850
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 848

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


854
855
856
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 854

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


859
860
861
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 859

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


864
865
866
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 864

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



871
872
873
874
875
876
877
878
879
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 871

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end