Class: Google::Apis::OsconfigV1beta::LookupEffectiveGuestPolicyRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

A request message for getting the effective guest policy assigned to the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LookupEffectiveGuestPolicyRequest

Returns a new instance of LookupEffectiveGuestPolicyRequest.



1144
1145
1146
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1144

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#os_architectureString

Architecture of OS running on the instance. The OS Config agent only provides this field for targeting if OS Inventory is enabled for that instance. Corresponds to the JSON property osArchitecture

Returns:

  • (String)


1130
1131
1132
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1130

def os_architecture
  @os_architecture
end

#os_short_nameString

Short name of the OS running on the instance. The OS Config agent only provides this field for targeting if OS Inventory is enabled for that instance. Corresponds to the JSON property osShortName

Returns:

  • (String)


1136
1137
1138
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1136

def os_short_name
  @os_short_name
end

#os_versionString

Version of the OS running on the instance. The OS Config agent only provides this field for targeting if OS Inventory is enabled for that VM instance. Corresponds to the JSON property osVersion

Returns:

  • (String)


1142
1143
1144
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1142

def os_version
  @os_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1149
1150
1151
1152
1153
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1149

def update!(**args)
  @os_architecture = args[:os_architecture] if args.key?(:os_architecture)
  @os_short_name = args[:os_short_name] if args.key?(:os_short_name)
  @os_version = args[:os_version] if args.key?(:os_version)
end