Class: Google::Apis::OsconfigV1beta::PatchDeployment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Patch deployments are configurations that individual patch jobs use to complete a patch. These configurations include instance filter, package repository settings, and a schedule. For more information about creating and managing patch deployments, see Scheduling patch jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PatchDeployment

Returns a new instance of PatchDeployment.



1353
1354
1355
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1353

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time the patch deployment was created. Timestamp is in RFC3339 text format. Corresponds to the JSON property createTime

Returns:

  • (String)


1285
1286
1287
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1285

def create_time
  @create_time
end

#descriptionString

Optional. Description of the patch deployment. Length of the description is limited to 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


1291
1292
1293
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1291

def description
  @description
end

#durationString

Optional. Duration of the patch. After the duration ends, the patch times out. Corresponds to the JSON property duration

Returns:

  • (String)


1296
1297
1298
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1296

def duration
  @duration
end

#instance_filterGoogle::Apis::OsconfigV1beta::PatchInstanceFilter

A filter to target VM instances for patching. The targeted VMs must meet all criteria specified. So if both labels and zones are specified, the patch job targets only VMs with those labels and in those zones. Corresponds to the JSON property instanceFilter



1303
1304
1305
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1303

def instance_filter
  @instance_filter
end

#last_execute_timeString

Output only. The last time a patch job was started by this deployment. Timestamp is in RFC3339 text format. Corresponds to the JSON property lastExecuteTime

Returns:

  • (String)


1309
1310
1311
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1309

def last_execute_time
  @last_execute_time
end

#nameString

Unique name for the patch deployment resource in a project. The patch deployment name is in the form: projects/project_id/patchDeployments/ patch_deployment_id`. This field is ignored when you create a new patch deployment. Corresponds to the JSON propertyname`

Returns:

  • (String)


1317
1318
1319
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1317

def name
  @name
end

#one_time_scheduleGoogle::Apis::OsconfigV1beta::OneTimeSchedule

Sets the time for a one time patch deployment. Timestamp is in RFC3339 text format. Corresponds to the JSON property oneTimeSchedule



1323
1324
1325
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1323

def one_time_schedule
  @one_time_schedule
end

#patch_configGoogle::Apis::OsconfigV1beta::PatchConfig

Patch configuration specifications. Contains details on how to apply the patch( es) to a VM instance. Corresponds to the JSON property patchConfig



1329
1330
1331
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1329

def patch_config
  @patch_config
end

#recurring_scheduleGoogle::Apis::OsconfigV1beta::RecurringSchedule

Sets the time for recurring patch deployments. Corresponds to the JSON property recurringSchedule



1334
1335
1336
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1334

def recurring_schedule
  @recurring_schedule
end

#rolloutGoogle::Apis::OsconfigV1beta::PatchRollout

Patch rollout configuration specifications. Contains details on the concurrency control when applying patch(es) to all targeted VMs. Corresponds to the JSON property rollout



1340
1341
1342
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1340

def rollout
  @rollout
end

#stateString

Output only. Current state of the patch deployment. Corresponds to the JSON property state

Returns:

  • (String)


1345
1346
1347
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1345

def state
  @state
end

#update_timeString

Output only. Time the patch deployment was last updated. Timestamp is in RFC3339 text format. Corresponds to the JSON property updateTime

Returns:

  • (String)


1351
1352
1353
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1351

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1358

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @duration = args[:duration] if args.key?(:duration)
  @instance_filter = args[:instance_filter] if args.key?(:instance_filter)
  @last_execute_time = args[:last_execute_time] if args.key?(:last_execute_time)
  @name = args[:name] if args.key?(:name)
  @one_time_schedule = args[:one_time_schedule] if args.key?(:one_time_schedule)
  @patch_config = args[:patch_config] if args.key?(:patch_config)
  @recurring_schedule = args[:recurring_schedule] if args.key?(:recurring_schedule)
  @rollout = args[:rollout] if args.key?(:rollout)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end