Class: Google::Apis::OsconfigV1beta::SoftwareRecipeArtifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Specifies a resource to be used in the recipe.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SoftwareRecipeArtifact

Returns a new instance of SoftwareRecipeArtifact.



1959
1960
1961
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1959

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_insecureBoolean Also known as: allow_insecure?

Defaults to false. When false, recipes are subject to validations based on the artifact type: Remote: A checksum must be specified, and only protocols with transport-layer security are permitted. GCS: An object generation number must be specified. Corresponds to the JSON property allowInsecure

Returns:

  • (Boolean)


1940
1941
1942
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1940

def allow_insecure
  @allow_insecure
end

#gcsGoogle::Apis::OsconfigV1beta::SoftwareRecipeArtifactGcs

Specifies an artifact available as a Google Cloud Storage object. Corresponds to the JSON property gcs



1946
1947
1948
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1946

def gcs
  @gcs
end

#idString

Required. Id of the artifact, which the installation and update steps of this recipe can reference. Artifacts in a recipe cannot have the same id. Corresponds to the JSON property id

Returns:

  • (String)


1952
1953
1954
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1952

def id
  @id
end

#remoteGoogle::Apis::OsconfigV1beta::SoftwareRecipeArtifactRemote

Specifies an artifact available via some URI. Corresponds to the JSON property remote



1957
1958
1959
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1957

def remote
  @remote
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1964
1965
1966
1967
1968
1969
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1964

def update!(**args)
  @allow_insecure = args[:allow_insecure] if args.key?(:allow_insecure)
  @gcs = args[:gcs] if args.key?(:gcs)
  @id = args[:id] if args.key?(:id)
  @remote = args[:remote] if args.key?(:remote)
end