Class: Google::Apis::OsconfigV1beta::SoftwareRecipeArtifactRemote

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Specifies an artifact available via some URI.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SoftwareRecipeArtifactRemote

Returns a new instance of SoftwareRecipeArtifactRemote.



2028
2029
2030
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2028

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checksumString

Must be provided if allow_insecure is false. SHA256 checksum in hex format, to compare to the checksum of the artifact. If the checksum is not empty and it doesn't match the artifact then the recipe installation fails before running any of the steps. Corresponds to the JSON property checksum

Returns:

  • (String)


2020
2021
2022
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2020

def checksum
  @checksum
end

#uriString

URI from which to fetch the object. It should contain both the protocol and path following the format protocol://location. Corresponds to the JSON property uri

Returns:

  • (String)


2026
2027
2028
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2026

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2033
2034
2035
2036
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2033

def update!(**args)
  @checksum = args[:checksum] if args.key?(:checksum)
  @uri = args[:uri] if args.key?(:uri)
end