Class: Google::Apis::OsconfigV1beta::SoftwareRecipeStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

An action that can be taken as part of installing or updating a recipe.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SoftwareRecipeStep

Returns a new instance of SoftwareRecipeStep.



2255
2256
2257
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#archive_extractionGoogle::Apis::OsconfigV1beta::SoftwareRecipeStepExtractArchive

Extracts an archive of the type specified in the specified directory. Corresponds to the JSON property archiveExtraction



2223
2224
2225
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2223

def archive_extraction
  @archive_extraction
end

#dpkg_installationGoogle::Apis::OsconfigV1beta::SoftwareRecipeStepInstallDpkg

Installs a deb via dpkg. Corresponds to the JSON property dpkgInstallation



2228
2229
2230
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2228

def dpkg_installation
  @dpkg_installation
end

#file_copyGoogle::Apis::OsconfigV1beta::SoftwareRecipeStepCopyFile

Copies the artifact to the specified path on the instance. Corresponds to the JSON property fileCopy



2233
2234
2235
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2233

def file_copy
  @file_copy
end

#file_execGoogle::Apis::OsconfigV1beta::SoftwareRecipeStepExecFile

Executes an artifact or local file. Corresponds to the JSON property fileExec



2238
2239
2240
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2238

def file_exec
  @file_exec
end

#msi_installationGoogle::Apis::OsconfigV1beta::SoftwareRecipeStepInstallMsi

Installs an MSI file. Corresponds to the JSON property msiInstallation



2243
2244
2245
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2243

def msi_installation
  @msi_installation
end

#rpm_installationGoogle::Apis::OsconfigV1beta::SoftwareRecipeStepInstallRpm

Installs an rpm file via the rpm utility. Corresponds to the JSON property rpmInstallation



2248
2249
2250
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2248

def rpm_installation
  @rpm_installation
end

#script_runGoogle::Apis::OsconfigV1beta::SoftwareRecipeStepRunScript

Runs a script through an interpreter. Corresponds to the JSON property scriptRun



2253
2254
2255
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2253

def script_run
  @script_run
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2260
2261
2262
2263
2264
2265
2266
2267
2268
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2260

def update!(**args)
  @archive_extraction = args[:archive_extraction] if args.key?(:archive_extraction)
  @dpkg_installation = args[:dpkg_installation] if args.key?(:dpkg_installation)
  @file_copy = args[:file_copy] if args.key?(:file_copy)
  @file_exec = args[:file_exec] if args.key?(:file_exec)
  @msi_installation = args[:msi_installation] if args.key?(:msi_installation)
  @rpm_installation = args[:rpm_installation] if args.key?(:rpm_installation)
  @script_run = args[:script_run] if args.key?(:script_run)
end