Class: Google::Apis::OsconfigV1beta::SoftwareRecipeStepCopyFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Copies the artifact to the specified path on the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SoftwareRecipeStepCopyFile

Returns a new instance of SoftwareRecipeStepCopyFile.



2128
2129
2130
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_idString

Required. The id of the relevant artifact in the recipe. Corresponds to the JSON property artifactId

Returns:

  • (String)


2101
2102
2103
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2101

def artifact_id
  @artifact_id
end

#destinationString

Required. The absolute path on the instance to put the file. Corresponds to the JSON property destination

Returns:

  • (String)


2106
2107
2108
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2106

def destination
  @destination
end

#overwriteBoolean Also known as: overwrite?

Whether to allow this step to overwrite existing files. If this is false and the file already exists the file is not overwritten and the step is considered a success. Defaults to false. Corresponds to the JSON property overwrite

Returns:

  • (Boolean)


2113
2114
2115
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2113

def overwrite
  @overwrite
end

#permissionsString

Consists of three octal digits which represent, in order, the permissions of the owner, group, and other users for the file (similarly to the numeric mode used in the linux chmod utility). Each digit represents a three bit number with the 4 bit corresponding to the read permissions, the 2 bit corresponds to the write bit, and the one bit corresponds to the execute permission. Default behavior is 755. Below are some examples of permissions and their associated values: read, write, and execute: 7 read and execute: 5 read and write: 6 read only: 4 Corresponds to the JSON property permissions

Returns:

  • (String)


2126
2127
2128
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2126

def permissions
  @permissions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2133
2134
2135
2136
2137
2138
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2133

def update!(**args)
  @artifact_id = args[:artifact_id] if args.key?(:artifact_id)
  @destination = args[:destination] if args.key?(:destination)
  @overwrite = args[:overwrite] if args.key?(:overwrite)
  @permissions = args[:permissions] if args.key?(:permissions)
end