Class: Google::Apis::OsconfigV1beta::SoftwareRecipeStepExecFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Executes an artifact or local file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SoftwareRecipeStepExecFile

Returns a new instance of SoftwareRecipeStepExecFile.



2166
2167
2168
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_exit_codesArray<Fixnum>

Defaults to [0]. A list of possible return values that the program can return to indicate a success. Corresponds to the JSON property allowedExitCodes

Returns:

  • (Array<Fixnum>)


2149
2150
2151
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2149

def allowed_exit_codes
  @allowed_exit_codes
end

#argsArray<String>

Arguments to be passed to the provided executable. Corresponds to the JSON property args

Returns:

  • (Array<String>)


2154
2155
2156
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2154

def args
  @args
end

#artifact_idString

The id of the relevant artifact in the recipe. Corresponds to the JSON property artifactId

Returns:

  • (String)


2159
2160
2161
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2159

def artifact_id
  @artifact_id
end

#local_pathString

The absolute path of the file on the local filesystem. Corresponds to the JSON property localPath

Returns:

  • (String)


2164
2165
2166
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2164

def local_path
  @local_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2171
2172
2173
2174
2175
2176
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2171

def update!(**args)
  @allowed_exit_codes = args[:allowed_exit_codes] if args.key?(:allowed_exit_codes)
  @args = args[:args] if args.key?(:args)
  @artifact_id = args[:artifact_id] if args.key?(:artifact_id)
  @local_path = args[:local_path] if args.key?(:local_path)
end