Class: Google::Apis::OsconfigV1beta::SoftwareRecipeStepExtractArchive

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Extracts an archive of the type specified in the specified directory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SoftwareRecipeStepExtractArchive

Returns a new instance of SoftwareRecipeStepExtractArchive.



2198
2199
2200
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2198

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_idString

Required. The id of the relevant artifact in the recipe. Corresponds to the JSON property artifactId

Returns:

  • (String)


2186
2187
2188
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2186

def artifact_id
  @artifact_id
end

#destinationString

Directory to extract archive to. Defaults to / on Linux or C:\ on Windows. Corresponds to the JSON property destination

Returns:

  • (String)


2191
2192
2193
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2191

def destination
  @destination
end

#typeString

Required. The type of the archive to extract. Corresponds to the JSON property type

Returns:

  • (String)


2196
2197
2198
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2196

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2203
2204
2205
2206
2207
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2203

def update!(**args)
  @artifact_id = args[:artifact_id] if args.key?(:artifact_id)
  @destination = args[:destination] if args.key?(:destination)
  @type = args[:type] if args.key?(:type)
end