Class: Google::Apis::OsconfigV1beta::SoftwareRecipeStepInstallMsi

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Installs an MSI file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SoftwareRecipeStepInstallMsi

Returns a new instance of SoftwareRecipeStepInstallMsi.



2250
2251
2252
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2250

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_exit_codesArray<Fixnum>

Return codes that indicate that the software installed or updated successfully. Behaviour defaults to [0] Corresponds to the JSON property allowedExitCodes

Returns:

  • (Array<Fixnum>)


2237
2238
2239
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2237

def allowed_exit_codes
  @allowed_exit_codes
end

#artifact_idString

Required. The id of the relevant artifact in the recipe. Corresponds to the JSON property artifactId

Returns:

  • (String)


2242
2243
2244
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2242

def artifact_id
  @artifact_id
end

#flagsArray<String>

The flags to use when installing the MSI defaults to "/i". Corresponds to the JSON property flags

Returns:

  • (Array<String>)


2248
2249
2250
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2248

def flags
  @flags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2255
2256
2257
2258
2259
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2255

def update!(**args)
  @allowed_exit_codes = args[:allowed_exit_codes] if args.key?(:allowed_exit_codes)
  @artifact_id = args[:artifact_id] if args.key?(:artifact_id)
  @flags = args[:flags] if args.key?(:flags)
end