Class: Google::Apis::OsconfigV1beta::YumSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Yum patching is performed by executing yum update. Additional options can be set to control how this is executed. Note that not all settings are supported on all platforms.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ YumSettings

Returns a new instance of YumSettings.



2606
2607
2608
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2606

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#excludesArray<String>

List of packages to exclude from update. These packages are excluded by using the yum --exclude flag. Corresponds to the JSON property excludes

Returns:

  • (Array<String>)


2585
2586
2587
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2585

def excludes
  @excludes
end

#exclusive_packagesArray<String>

An exclusive list of packages to be updated. These are the only packages that will be updated. If these packages are not installed, they will be ignored. This field must not be specified with any other patch configuration fields. Corresponds to the JSON property exclusivePackages

Returns:

  • (Array<String>)


2592
2593
2594
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2592

def exclusive_packages
  @exclusive_packages
end

#minimalBoolean Also known as: minimal?

Will cause patch to run yum update-minimal instead. Corresponds to the JSON property minimal

Returns:

  • (Boolean)


2597
2598
2599
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2597

def minimal
  @minimal
end

#securityBoolean Also known as: security?

Adds the --security flag to yum update. Not supported on all platforms. Corresponds to the JSON property security

Returns:

  • (Boolean)


2603
2604
2605
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2603

def security
  @security
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2611
2612
2613
2614
2615
2616
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2611

def update!(**args)
  @excludes = args[:excludes] if args.key?(:excludes)
  @exclusive_packages = args[:exclusive_packages] if args.key?(:exclusive_packages)
  @minimal = args[:minimal] if args.key?(:minimal)
  @security = args[:security] if args.key?(:security)
end