Class: Google::Apis::OsconfigV1beta::ZypperRepository
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1beta::ZypperRepository
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb
Overview
Represents a single Zypper package repository. This repository is added to a
repo file that is stored at /etc/zypp/repos.d/google_osconfig.repo.
Instance Attribute Summary collapse
-
#base_url ⇒ String
Required.
-
#display_name ⇒ String
The display name of the repository.
-
#gpg_keys ⇒ Array<String>
URIs of GPG keys.
-
#id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ZypperRepository
constructor
A new instance of ZypperRepository.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ZypperRepository
Returns a new instance of ZypperRepository.
2647 2648 2649 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2647 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_url ⇒ String
Required. The location of the repository directory.
Corresponds to the JSON property baseUrl
2627 2628 2629 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2627 def base_url @base_url end |
#display_name ⇒ String
The display name of the repository.
Corresponds to the JSON property displayName
2632 2633 2634 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2632 def display_name @display_name end |
#gpg_keys ⇒ Array<String>
URIs of GPG keys.
Corresponds to the JSON property gpgKeys
2637 2638 2639 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2637 def gpg_keys @gpg_keys end |
#id ⇒ String
Required. A one word, unique name for this repository. This is the repo id
in the zypper config file and also the display_name if display_name is
omitted. This id is also used as the unique identifier when checking for guest
policy conflicts.
Corresponds to the JSON property id
2645 2646 2647 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2645 def id @id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2652 2653 2654 2655 2656 2657 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2652 def update!(**args) @base_url = args[:base_url] if args.key?(:base_url) @display_name = args[:display_name] if args.key?(:display_name) @gpg_keys = args[:gpg_keys] if args.key?(:gpg_keys) @id = args[:id] if args.key?(:id) end |