Class: Google::Apis::OsconfigV1beta::GuestPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

An OS Config resource representing a guest configuration policy. These policies represent the desired state for VM instance guest environments including packages to install or remove, package repository configurations, and software to install.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GuestPolicy

Returns a new instance of GuestPolicy.



1003
1004
1005
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assignmentGoogle::Apis::OsconfigV1beta::Assignment

An assignment represents the group or groups of VM instances that the policy applies to. If an assignment is empty, it applies to all VM instances. Otherwise, the targeted VM instances must meet all the criteria specified. So if both labels and zones are specified, the policy applies to VM instances with those labels and in those zones. Corresponds to the JSON property assignment



955
956
957
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 955

def assignment
  @assignment
end

#create_timeString

Output only. Time this guest policy was created. Corresponds to the JSON property createTime

Returns:

  • (String)


960
961
962
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 960

def create_time
  @create_time
end

#descriptionString

Description of the guest policy. Length of the description is limited to 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


966
967
968
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 966

def description
  @description
end

#etagString

The etag for this guest policy. If this is provided on update, it must match the server's etag. Corresponds to the JSON property etag

Returns:

  • (String)


972
973
974
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 972

def etag
  @etag
end

#nameString

Required. Unique name of the resource in this project using one of the following forms: projects/project_number/guestPolicies/guest_policy_id`. Corresponds to the JSON propertyname`

Returns:

  • (String)


978
979
980
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 978

def name
  @name
end

#package_repositoriesArray<Google::Apis::OsconfigV1beta::PackageRepository>

A list of package repositories to configure on the VM instance. This is done before any other configs are applied so they can use these repos. Package repositories are only configured if the corresponding package manager(s) are available. Corresponds to the JSON property packageRepositories



986
987
988
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 986

def package_repositories
  @package_repositories
end

#packagesArray<Google::Apis::OsconfigV1beta::Package>

The software packages to be managed by this policy. Corresponds to the JSON property packages



991
992
993
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 991

def packages
  @packages
end

#recipesArray<Google::Apis::OsconfigV1beta::SoftwareRecipe>

A list of Recipes to install on the VM instance. Corresponds to the JSON property recipes



996
997
998
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 996

def recipes
  @recipes
end

#update_timeString

Output only. Last time this guest policy was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1001
1002
1003
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1001

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1008

def update!(**args)
  @assignment = args[:assignment] if args.key?(:assignment)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @package_repositories = args[:package_repositories] if args.key?(:package_repositories)
  @packages = args[:packages] if args.key?(:packages)
  @recipes = args[:recipes] if args.key?(:recipes)
  @update_time = args[:update_time] if args.key?(:update_time)
end