Class: Google::Apis::OsconfigV1beta::PatchConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Patch configuration specifications. Contains details on how to apply the patch( es) to a VM instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PatchConfig

Returns a new instance of PatchConfig.



1431
1432
1433
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aptGoogle::Apis::OsconfigV1beta::AptSettings

Apt patching is completed by executing apt-get update && apt-get upgrade. Additional options can be set to control how this is executed. Corresponds to the JSON property apt



1370
1371
1372
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1370

def apt
  @apt
end

#gooGoogle::Apis::OsconfigV1beta::GooSettings

Googet patching is performed by running googet update. Corresponds to the JSON property goo



1375
1376
1377
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1375

def goo
  @goo
end

#mig_instances_allowedBoolean Also known as: mig_instances_allowed?

Allows the patch job to run on Managed instance groups (MIGs). Corresponds to the JSON property migInstancesAllowed

Returns:

  • (Boolean)


1380
1381
1382
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1380

def mig_instances_allowed
  @mig_instances_allowed
end

#post_stepGoogle::Apis::OsconfigV1beta::ExecStep

A step that runs an executable for a PatchJob. Corresponds to the JSON property postStep



1386
1387
1388
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1386

def post_step
  @post_step
end

#pre_stepGoogle::Apis::OsconfigV1beta::ExecStep

A step that runs an executable for a PatchJob. Corresponds to the JSON property preStep



1391
1392
1393
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1391

def pre_step
  @pre_step
end

#reboot_configString

Post-patch reboot settings. Corresponds to the JSON property rebootConfig

Returns:

  • (String)


1396
1397
1398
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1396

def reboot_config
  @reboot_config
end

#skip_unpatchable_vmsBoolean Also known as: skip_unpatchable_vms?

Optional. Enables enhanced reporting for the patch job: 1. The patch job skips instances that cannot be patched and reports them as SKIPPED. An instance cannot be patched for two reasons: 1. The instance runs Container-Optimized OS (COS), which cannot be patched. 2. The instance is part of a managed instance group (MIG), and patching MIG instances is disabled in the patch job's configuration (PatchConfig.migInstancesAllowed is false). 2. The patch job is reported as SUCCEEDED if it completes without errors, even if some instances are SKIPPED. 3. The patch job is reported as COMPLETED_WITH_INACTIVE_VMS if it completes without errors, but does not patch instances that are INACTIVE. Corresponds to the JSON property skipUnpatchableVms

Returns:

  • (Boolean)


1410
1411
1412
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1410

def skip_unpatchable_vms
  @skip_unpatchable_vms
end

#windows_updateGoogle::Apis::OsconfigV1beta::WindowsUpdateSettings

Windows patching is performed using the Windows Update Agent. Corresponds to the JSON property windowsUpdate



1416
1417
1418
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1416

def windows_update
  @windows_update
end

#yumGoogle::Apis::OsconfigV1beta::YumSettings

Yum patching is performed by executing yum update. Additional options can be set to control how this is executed. Note that not all settings are supported on all platforms. Corresponds to the JSON property yum



1423
1424
1425
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1423

def yum
  @yum
end

#zypperGoogle::Apis::OsconfigV1beta::ZypperSettings

Zypper patching is performed by running zypper patch. See also https://en. opensuse.org/SDB:Zypper_manual. Corresponds to the JSON property zypper



1429
1430
1431
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1429

def zypper
  @zypper
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1436

def update!(**args)
  @apt = args[:apt] if args.key?(:apt)
  @goo = args[:goo] if args.key?(:goo)
  @mig_instances_allowed = args[:mig_instances_allowed] if args.key?(:mig_instances_allowed)
  @post_step = args[:post_step] if args.key?(:post_step)
  @pre_step = args[:pre_step] if args.key?(:pre_step)
  @reboot_config = args[:reboot_config] if args.key?(:reboot_config)
  @skip_unpatchable_vms = args[:skip_unpatchable_vms] if args.key?(:skip_unpatchable_vms)
  @windows_update = args[:windows_update] if args.key?(:windows_update)
  @yum = args[:yum] if args.key?(:yum)
  @zypper = args[:zypper] if args.key?(:zypper)
end