Class: Google::Apis::OsconfigV1beta::PatchJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

A high level representation of a patch job that is either in progress or has completed. Instance details are not included in the job. To paginate through instance details, use ListPatchJobInstanceDetails. For more information about patch jobs, see Creating patch jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PatchJob

Returns a new instance of PatchJob.



1721
1722
1723
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Time this patch job was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1638
1639
1640
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1638

def create_time
  @create_time
end

#descriptionString

Description of the patch job. Length of the description is limited to 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


1644
1645
1646
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1644

def description
  @description
end

#display_nameString

Display name for this patch job. This is not a unique identifier. Corresponds to the JSON property displayName

Returns:

  • (String)


1649
1650
1651
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1649

def display_name
  @display_name
end

#dry_runBoolean Also known as: dry_run?

If this patch job is a dry run, the agent reports that it has finished without running any updates on the VM instance. Corresponds to the JSON property dryRun

Returns:

  • (Boolean)


1655
1656
1657
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1655

def dry_run
  @dry_run
end

#durationString

Duration of the patch job. After the duration ends, the patch job times out. Corresponds to the JSON property duration

Returns:

  • (String)


1661
1662
1663
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1661

def duration
  @duration
end

#error_messageString

If this patch job failed, this message provides information about the failure. Corresponds to the JSON property errorMessage

Returns:

  • (String)


1666
1667
1668
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1666

def error_message
  @error_message
end

#instance_details_summaryGoogle::Apis::OsconfigV1beta::PatchJobInstanceDetailsSummary

A summary of the current patch state across all instances that this patch job affects. Contains counts of instances in different states. These states map to InstancePatchState. List patch job instance details to see the specific states of each instance. Corresponds to the JSON property instanceDetailsSummary



1674
1675
1676
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1674

def instance_details_summary
  @instance_details_summary
end

#instance_filterGoogle::Apis::OsconfigV1beta::PatchInstanceFilter

A filter to target VM instances for patching. The targeted VMs must meet all criteria specified. So if both labels and zones are specified, the patch job targets only VMs with those labels and in those zones. Corresponds to the JSON property instanceFilter



1681
1682
1683
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1681

def instance_filter
  @instance_filter
end

#nameString

Unique identifier for this patch job in the form projects/*/patchJobs/* Corresponds to the JSON property name

Returns:

  • (String)


1686
1687
1688
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1686

def name
  @name
end

#patch_configGoogle::Apis::OsconfigV1beta::PatchConfig

Patch configuration specifications. Contains details on how to apply the patch( es) to a VM instance. Corresponds to the JSON property patchConfig



1692
1693
1694
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1692

def patch_config
  @patch_config
end

#patch_deploymentString

Output only. Name of the patch deployment that created this patch job. Corresponds to the JSON property patchDeployment

Returns:

  • (String)


1697
1698
1699
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1697

def patch_deployment
  @patch_deployment
end

#percent_completeFloat

Reflects the overall progress of the patch job in the range of 0.0 being no progress to 100.0 being complete. Corresponds to the JSON property percentComplete

Returns:

  • (Float)


1703
1704
1705
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1703

def percent_complete
  @percent_complete
end

#rolloutGoogle::Apis::OsconfigV1beta::PatchRollout

Patch rollout configuration specifications. Contains details on the concurrency control when applying patch(es) to all targeted VMs. Corresponds to the JSON property rollout



1709
1710
1711
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1709

def rollout
  @rollout
end

#stateString

The current state of the PatchJob. Corresponds to the JSON property state

Returns:

  • (String)


1714
1715
1716
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1714

def state
  @state
end

#update_timeString

Last time this patch job was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1719
1720
1721
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1719

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1726

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @dry_run = args[:dry_run] if args.key?(:dry_run)
  @duration = args[:duration] if args.key?(:duration)
  @error_message = args[:error_message] if args.key?(:error_message)
  @instance_details_summary = args[:instance_details_summary] if args.key?(:instance_details_summary)
  @instance_filter = args[:instance_filter] if args.key?(:instance_filter)
  @name = args[:name] if args.key?(:name)
  @patch_config = args[:patch_config] if args.key?(:patch_config)
  @patch_deployment = args[:patch_deployment] if args.key?(:patch_deployment)
  @percent_complete = args[:percent_complete] if args.key?(:percent_complete)
  @rollout = args[:rollout] if args.key?(:rollout)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end