Class: Google::Apis::OsconfigV1beta::PatchJobInstanceDetailsSummary
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1beta::PatchJobInstanceDetailsSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb
Overview
A summary of the current patch state across all instances that this patch job
affects. Contains counts of instances in different states. These states map to
InstancePatchState. List patch job instance details to see the specific
states of each instance.
Instance Attribute Summary collapse
-
#acked_instance_count ⇒ Fixnum
Number of instances that have acked and will start shortly.
-
#applying_patches_instance_count ⇒ Fixnum
Number of instances that are applying patches.
-
#downloading_patches_instance_count ⇒ Fixnum
Number of instances that are downloading patches.
-
#failed_instance_count ⇒ Fixnum
Number of instances that failed.
-
#inactive_instance_count ⇒ Fixnum
Number of instances that are inactive.
-
#no_agent_detected_instance_count ⇒ Fixnum
Number of instances that do not appear to be running the agent.
-
#notified_instance_count ⇒ Fixnum
Number of instances notified about patch job.
-
#pending_instance_count ⇒ Fixnum
Number of instances pending patch job.
-
#post_patch_step_instance_count ⇒ Fixnum
Number of instances that are running the post-patch step.
-
#pre_patch_step_instance_count ⇒ Fixnum
Number of instances that are running the pre-patch step.
-
#rebooting_instance_count ⇒ Fixnum
Number of instances rebooting.
-
#skipped_instance_count ⇒ Fixnum
Number of instances that were skipped during patching.
-
#started_instance_count ⇒ Fixnum
Number of instances that have started.
-
#succeeded_instance_count ⇒ Fixnum
Number of instances that have completed successfully.
-
#succeeded_reboot_required_instance_count ⇒ Fixnum
Number of instances that require reboot.
-
#timed_out_instance_count ⇒ Fixnum
Number of instances that exceeded the time out while applying the patch.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PatchJobInstanceDetailsSummary
constructor
A new instance of PatchJobInstanceDetailsSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PatchJobInstanceDetailsSummary
Returns a new instance of PatchJobInstanceDetailsSummary.
1704 1705 1706 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1704 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acked_instance_count ⇒ Fixnum
Number of instances that have acked and will start shortly.
Corresponds to the JSON property ackedInstanceCount
1625 1626 1627 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1625 def acked_instance_count @acked_instance_count end |
#applying_patches_instance_count ⇒ Fixnum
Number of instances that are applying patches.
Corresponds to the JSON property applyingPatchesInstanceCount
1630 1631 1632 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1630 def @applying_patches_instance_count end |
#downloading_patches_instance_count ⇒ Fixnum
Number of instances that are downloading patches.
Corresponds to the JSON property downloadingPatchesInstanceCount
1635 1636 1637 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1635 def downloading_patches_instance_count @downloading_patches_instance_count end |
#failed_instance_count ⇒ Fixnum
Number of instances that failed.
Corresponds to the JSON property failedInstanceCount
1640 1641 1642 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1640 def failed_instance_count @failed_instance_count end |
#inactive_instance_count ⇒ Fixnum
Number of instances that are inactive.
Corresponds to the JSON property inactiveInstanceCount
1645 1646 1647 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1645 def inactive_instance_count @inactive_instance_count end |
#no_agent_detected_instance_count ⇒ Fixnum
Number of instances that do not appear to be running the agent. Check to
ensure that the agent is installed, running, and able to communicate with the
service.
Corresponds to the JSON property noAgentDetectedInstanceCount
1652 1653 1654 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1652 def no_agent_detected_instance_count @no_agent_detected_instance_count end |
#notified_instance_count ⇒ Fixnum
Number of instances notified about patch job.
Corresponds to the JSON property notifiedInstanceCount
1657 1658 1659 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1657 def notified_instance_count @notified_instance_count end |
#pending_instance_count ⇒ Fixnum
Number of instances pending patch job.
Corresponds to the JSON property pendingInstanceCount
1662 1663 1664 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1662 def pending_instance_count @pending_instance_count end |
#post_patch_step_instance_count ⇒ Fixnum
Number of instances that are running the post-patch step.
Corresponds to the JSON property postPatchStepInstanceCount
1667 1668 1669 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1667 def post_patch_step_instance_count @post_patch_step_instance_count end |
#pre_patch_step_instance_count ⇒ Fixnum
Number of instances that are running the pre-patch step.
Corresponds to the JSON property prePatchStepInstanceCount
1672 1673 1674 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1672 def pre_patch_step_instance_count @pre_patch_step_instance_count end |
#rebooting_instance_count ⇒ Fixnum
Number of instances rebooting.
Corresponds to the JSON property rebootingInstanceCount
1677 1678 1679 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1677 def rebooting_instance_count @rebooting_instance_count end |
#skipped_instance_count ⇒ Fixnum
Number of instances that were skipped during patching.
Corresponds to the JSON property skippedInstanceCount
1682 1683 1684 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1682 def skipped_instance_count @skipped_instance_count end |
#started_instance_count ⇒ Fixnum
Number of instances that have started.
Corresponds to the JSON property startedInstanceCount
1687 1688 1689 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1687 def started_instance_count @started_instance_count end |
#succeeded_instance_count ⇒ Fixnum
Number of instances that have completed successfully.
Corresponds to the JSON property succeededInstanceCount
1692 1693 1694 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1692 def succeeded_instance_count @succeeded_instance_count end |
#succeeded_reboot_required_instance_count ⇒ Fixnum
Number of instances that require reboot.
Corresponds to the JSON property succeededRebootRequiredInstanceCount
1697 1698 1699 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1697 def succeeded_reboot_required_instance_count @succeeded_reboot_required_instance_count end |
#timed_out_instance_count ⇒ Fixnum
Number of instances that exceeded the time out while applying the patch.
Corresponds to the JSON property timedOutInstanceCount
1702 1703 1704 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1702 def timed_out_instance_count @timed_out_instance_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1709 def update!(**args) @acked_instance_count = args[:acked_instance_count] if args.key?(:acked_instance_count) @applying_patches_instance_count = args[:applying_patches_instance_count] if args.key?(:applying_patches_instance_count) @downloading_patches_instance_count = args[:downloading_patches_instance_count] if args.key?(:downloading_patches_instance_count) @failed_instance_count = args[:failed_instance_count] if args.key?(:failed_instance_count) @inactive_instance_count = args[:inactive_instance_count] if args.key?(:inactive_instance_count) @no_agent_detected_instance_count = args[:no_agent_detected_instance_count] if args.key?(:no_agent_detected_instance_count) @notified_instance_count = args[:notified_instance_count] if args.key?(:notified_instance_count) @pending_instance_count = args[:pending_instance_count] if args.key?(:pending_instance_count) @post_patch_step_instance_count = args[:post_patch_step_instance_count] if args.key?(:post_patch_step_instance_count) @pre_patch_step_instance_count = args[:pre_patch_step_instance_count] if args.key?(:pre_patch_step_instance_count) @rebooting_instance_count = args[:rebooting_instance_count] if args.key?(:rebooting_instance_count) @skipped_instance_count = args[:skipped_instance_count] if args.key?(:skipped_instance_count) @started_instance_count = args[:started_instance_count] if args.key?(:started_instance_count) @succeeded_instance_count = args[:succeeded_instance_count] if args.key?(:succeeded_instance_count) @succeeded_reboot_required_instance_count = args[:succeeded_reboot_required_instance_count] if args.key?(:succeeded_reboot_required_instance_count) @timed_out_instance_count = args[:timed_out_instance_count] if args.key?(:timed_out_instance_count) end |