Class: Google::Apis::OsconfigV1beta::RecurringSchedule
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1beta::RecurringSchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb
Overview
Sets the time for recurring patch deployments.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Optional.
-
#frequency ⇒ String
Required.
-
#last_execute_time ⇒ String
Output only.
-
#monthly ⇒ Google::Apis::OsconfigV1beta::MonthlySchedule
Represents a monthly schedule.
-
#next_execute_time ⇒ String
Output only.
-
#start_time ⇒ String
Optional.
-
#time_of_day ⇒ Google::Apis::OsconfigV1beta::TimeOfDay
Represents a time of day.
-
#time_zone ⇒ Google::Apis::OsconfigV1beta::TimeZone
Represents a time zone from the IANA Time Zone Database.
-
#weekly ⇒ Google::Apis::OsconfigV1beta::WeeklySchedule
Represents a weekly schedule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecurringSchedule
constructor
A new instance of RecurringSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecurringSchedule
Returns a new instance of RecurringSchedule.
1824 1825 1826 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1824 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Optional. The end time at which a recurring patch deployment schedule is no
longer active.
Corresponds to the JSON property endTime
1777 1778 1779 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1777 def end_time @end_time end |
#frequency ⇒ String
Required. The frequency unit of this recurring schedule.
Corresponds to the JSON property frequency
1782 1783 1784 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1782 def frequency @frequency end |
#last_execute_time ⇒ String
Output only. The time the last patch job ran successfully.
Corresponds to the JSON property lastExecuteTime
1787 1788 1789 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1787 def last_execute_time @last_execute_time end |
#monthly ⇒ Google::Apis::OsconfigV1beta::MonthlySchedule
Represents a monthly schedule. An example of a valid monthly schedule is "on
the third Tuesday of the month" or "on the 15th of the month".
Corresponds to the JSON property monthly
1793 1794 1795 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1793 def monthly @monthly end |
#next_execute_time ⇒ String
Output only. The time the next patch job is scheduled to run.
Corresponds to the JSON property nextExecuteTime
1798 1799 1800 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1798 def next_execute_time @next_execute_time end |
#start_time ⇒ String
Optional. The time that the recurring schedule becomes effective. Defaults to
create_time of the patch deployment.
Corresponds to the JSON property startTime
1804 1805 1806 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1804 def start_time @start_time end |
#time_of_day ⇒ Google::Apis::OsconfigV1beta::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property timeOfDay
1811 1812 1813 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1811 def time_of_day @time_of_day end |
#time_zone ⇒ Google::Apis::OsconfigV1beta::TimeZone
Represents a time zone from the IANA Time Zone Database.
Corresponds to the JSON property timeZone
1817 1818 1819 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1817 def time_zone @time_zone end |
#weekly ⇒ Google::Apis::OsconfigV1beta::WeeklySchedule
Represents a weekly schedule.
Corresponds to the JSON property weekly
1822 1823 1824 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1822 def weekly @weekly end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1829 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @frequency = args[:frequency] if args.key?(:frequency) @last_execute_time = args[:last_execute_time] if args.key?(:last_execute_time) @monthly = args[:monthly] if args.key?(:monthly) @next_execute_time = args[:next_execute_time] if args.key?(:next_execute_time) @start_time = args[:start_time] if args.key?(:start_time) @time_of_day = args[:time_of_day] if args.key?(:time_of_day) @time_zone = args[:time_zone] if args.key?(:time_zone) @weekly = args[:weekly] if args.key?(:weekly) end |