Class: Google::Apis::OsconfigV1beta::RecurringSchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Sets the time for recurring patch deployments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecurringSchedule

Returns a new instance of RecurringSchedule.



2001
2002
2003
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Optional. The end time at which a recurring patch deployment schedule is no longer active. Corresponds to the JSON property endTime

Returns:

  • (String)


1954
1955
1956
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1954

def end_time
  @end_time
end

#frequencyString

Required. The frequency unit of this recurring schedule. Corresponds to the JSON property frequency

Returns:

  • (String)


1959
1960
1961
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1959

def frequency
  @frequency
end

#last_execute_timeString

Output only. The time the last patch job ran successfully. Corresponds to the JSON property lastExecuteTime

Returns:

  • (String)


1964
1965
1966
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1964

def last_execute_time
  @last_execute_time
end

#monthlyGoogle::Apis::OsconfigV1beta::MonthlySchedule

Represents a monthly schedule. An example of a valid monthly schedule is "on the third Tuesday of the month" or "on the 15th of the month". Corresponds to the JSON property monthly



1970
1971
1972
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1970

def monthly
  @monthly
end

#next_execute_timeString

Output only. The time the next patch job is scheduled to run. Corresponds to the JSON property nextExecuteTime

Returns:

  • (String)


1975
1976
1977
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1975

def next_execute_time
  @next_execute_time
end

#start_timeString

Optional. The time that the recurring schedule becomes effective. Defaults to create_time of the patch deployment. Corresponds to the JSON property startTime

Returns:

  • (String)


1981
1982
1983
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1981

def start_time
  @start_time
end

#time_of_dayGoogle::Apis::OsconfigV1beta::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property timeOfDay



1988
1989
1990
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1988

def time_of_day
  @time_of_day
end

#time_zoneGoogle::Apis::OsconfigV1beta::TimeZone

Represents a time zone from the IANA Time Zone Database. Corresponds to the JSON property timeZone



1994
1995
1996
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1994

def time_zone
  @time_zone
end

#weeklyGoogle::Apis::OsconfigV1beta::WeeklySchedule

Represents a weekly schedule. Corresponds to the JSON property weekly



1999
2000
2001
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 1999

def weekly
  @weekly
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2006

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @frequency = args[:frequency] if args.key?(:frequency)
  @last_execute_time = args[:last_execute_time] if args.key?(:last_execute_time)
  @monthly = args[:monthly] if args.key?(:monthly)
  @next_execute_time = args[:next_execute_time] if args.key?(:next_execute_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @time_of_day = args[:time_of_day] if args.key?(:time_of_day)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @weekly = args[:weekly] if args.key?(:weekly)
end