Class: Google::Apis::OsconfigV1beta::SoftwareRecipeArtifactRemote

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Specifies an artifact available via some URI.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SoftwareRecipeArtifactRemote

Returns a new instance of SoftwareRecipeArtifactRemote.



2205
2206
2207
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2205

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checksumString

Must be provided if allow_insecure is false. SHA256 checksum in hex format, to compare to the checksum of the artifact. If the checksum is not empty and it doesn't match the artifact then the recipe installation fails before running any of the steps. Corresponds to the JSON property checksum

Returns:

  • (String)


2197
2198
2199
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2197

def checksum
  @checksum
end

#uriString

URI from which to fetch the object. It should contain both the protocol and path following the format protocol://location. Corresponds to the JSON property uri

Returns:

  • (String)


2203
2204
2205
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2203

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2210
2211
2212
2213
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2210

def update!(**args)
  @checksum = args[:checksum] if args.key?(:checksum)
  @uri = args[:uri] if args.key?(:uri)
end