Class: Google::Apis::OsconfigV1beta::SoftwareRecipeStepExtractArchive

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Extracts an archive of the type specified in the specified directory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SoftwareRecipeStepExtractArchive

Returns a new instance of SoftwareRecipeStepExtractArchive.



2375
2376
2377
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_idString

Required. The id of the relevant artifact in the recipe. Corresponds to the JSON property artifactId

Returns:

  • (String)


2363
2364
2365
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2363

def artifact_id
  @artifact_id
end

#destinationString

Directory to extract archive to. Defaults to / on Linux or C:\ on Windows. Corresponds to the JSON property destination

Returns:

  • (String)


2368
2369
2370
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2368

def destination
  @destination
end

#typeString

Required. The type of the archive to extract. Corresponds to the JSON property type

Returns:

  • (String)


2373
2374
2375
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2373

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2380
2381
2382
2383
2384
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2380

def update!(**args)
  @artifact_id = args[:artifact_id] if args.key?(:artifact_id)
  @destination = args[:destination] if args.key?(:destination)
  @type = args[:type] if args.key?(:type)
end