Class: Google::Apis::OsconfigV1beta::SoftwareRecipeStepInstallMsi

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Installs an MSI file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SoftwareRecipeStepInstallMsi

Returns a new instance of SoftwareRecipeStepInstallMsi.



2427
2428
2429
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2427

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_exit_codesArray<Fixnum>

Return codes that indicate that the software installed or updated successfully. Behaviour defaults to [0] Corresponds to the JSON property allowedExitCodes

Returns:

  • (Array<Fixnum>)


2414
2415
2416
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2414

def allowed_exit_codes
  @allowed_exit_codes
end

#artifact_idString

Required. The id of the relevant artifact in the recipe. Corresponds to the JSON property artifactId

Returns:

  • (String)


2419
2420
2421
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2419

def artifact_id
  @artifact_id
end

#flagsArray<String>

The flags to use when installing the MSI defaults to "/i". Corresponds to the JSON property flags

Returns:

  • (Array<String>)


2425
2426
2427
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2425

def flags
  @flags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2432
2433
2434
2435
2436
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2432

def update!(**args)
  @allowed_exit_codes = args[:allowed_exit_codes] if args.key?(:allowed_exit_codes)
  @artifact_id = args[:artifact_id] if args.key?(:artifact_id)
  @flags = args[:flags] if args.key?(:flags)
end