Class: Google::Apis::OsconfigV1beta::SoftwareRecipeStepRunScript
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1beta::SoftwareRecipeStepRunScript
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb
Overview
Runs a script through an interpreter.
Instance Attribute Summary collapse
-
#allowed_exit_codes ⇒ Array<Fixnum>
Return codes that indicate that the software installed or updated successfully.
-
#interpreter ⇒ String
The script interpreter to use to run the script.
-
#script ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SoftwareRecipeStepRunScript
constructor
A new instance of SoftwareRecipeStepRunScript.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SoftwareRecipeStepRunScript
Returns a new instance of SoftwareRecipeStepRunScript.
2303 2304 2305 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_exit_codes ⇒ Array<Fixnum>
Return codes that indicate that the software installed or updated successfully.
Behaviour defaults to [0]
Corresponds to the JSON property allowedExitCodes
2289 2290 2291 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2289 def allowed_exit_codes @allowed_exit_codes end |
#interpreter ⇒ String
The script interpreter to use to run the script. If no interpreter is
specified the script is executed directly, which likely only succeed for
scripts with shebang lines.
Corresponds to the JSON property interpreter
2296 2297 2298 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2296 def interpreter @interpreter end |
#script ⇒ String
Required. The shell script to be executed.
Corresponds to the JSON property script
2301 2302 2303 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2301 def script @script end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2308 2309 2310 2311 2312 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2308 def update!(**args) @allowed_exit_codes = args[:allowed_exit_codes] if args.key?(:allowed_exit_codes) @interpreter = args[:interpreter] if args.key?(:interpreter) @script = args[:script] if args.key?(:script) end |