Class: Google::Apis::OsconfigV1beta::SoftwareRecipeStepRunScript
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1beta::SoftwareRecipeStepRunScript
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb
Overview
Runs a script through an interpreter.
Instance Attribute Summary collapse
-
#allowed_exit_codes ⇒ Array<Fixnum>
Return codes that indicate that the software installed or updated successfully.
-
#interpreter ⇒ String
The script interpreter to use to run the script.
-
#script ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SoftwareRecipeStepRunScript
constructor
A new instance of SoftwareRecipeStepRunScript.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SoftwareRecipeStepRunScript
Returns a new instance of SoftwareRecipeStepRunScript.
2480 2481 2482 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2480 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_exit_codes ⇒ Array<Fixnum>
Return codes that indicate that the software installed or updated successfully.
Behaviour defaults to [0]
Corresponds to the JSON property allowedExitCodes
2466 2467 2468 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2466 def allowed_exit_codes @allowed_exit_codes end |
#interpreter ⇒ String
The script interpreter to use to run the script. If no interpreter is
specified the script is executed directly, which likely only succeed for
scripts with shebang lines.
Corresponds to the JSON property interpreter
2473 2474 2475 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2473 def interpreter @interpreter end |
#script ⇒ String
Required. The shell script to be executed.
Corresponds to the JSON property script
2478 2479 2480 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2478 def script @script end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2485 2486 2487 2488 2489 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2485 def update!(**args) @allowed_exit_codes = args[:allowed_exit_codes] if args.key?(:allowed_exit_codes) @interpreter = args[:interpreter] if args.key?(:interpreter) @script = args[:script] if args.key?(:script) end |