Class: Google::Apis::OsconfigV1beta::TimeOfDay

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeOfDay

Returns a new instance of TimeOfDay.



2582
2583
2584
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2582

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hoursFixnum

Hours of a day in 24 hour format. Must be greater than or equal to 0 and typically must be less than or equal to 23. An API may choose to allow the value "24:00:00" for scenarios like business closing time. Corresponds to the JSON property hours

Returns:

  • (Fixnum)


2561
2562
2563
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2561

def hours
  @hours
end

#minutesFixnum

Minutes of an hour. Must be greater than or equal to 0 and less than or equal to 59. Corresponds to the JSON property minutes

Returns:

  • (Fixnum)


2567
2568
2569
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2567

def minutes
  @minutes
end

#nanosFixnum

Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and less than or equal to 999,999,999. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


2573
2574
2575
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2573

def nanos
  @nanos
end

#secondsFixnum

Seconds of a minute. Must be greater than or equal to 0 and typically must be less than or equal to 59. An API may allow the value 60 if it allows leap- seconds. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


2580
2581
2582
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2580

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2587
2588
2589
2590
2591
2592
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2587

def update!(**args)
  @hours = args[:hours] if args.key?(:hours)
  @minutes = args[:minutes] if args.key?(:minutes)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
end