Class: Google::Apis::OsconfigV1beta::WindowsUpdateSettings
- Inherits:
-
Object
- Object
- Google::Apis::OsconfigV1beta::WindowsUpdateSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb
Overview
Windows patching is performed using the Windows Update Agent.
Instance Attribute Summary collapse
-
#classifications ⇒ Array<String>
Only apply updates of these windows update classifications.
-
#excludes ⇒ Array<String>
List of KBs to exclude from update.
-
#exclusive_patches ⇒ Array<String>
An exclusive list of kbs to be updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WindowsUpdateSettings
constructor
A new instance of WindowsUpdateSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WindowsUpdateSettings
Returns a new instance of WindowsUpdateSettings.
2522 2523 2524 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2522 def initialize(**args) update!(**args) end |
Instance Attribute Details
#classifications ⇒ Array<String>
Only apply updates of these windows update classifications. If empty, all
updates are applied.
Corresponds to the JSON property classifications
2509 2510 2511 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2509 def classifications @classifications end |
#excludes ⇒ Array<String>
List of KBs to exclude from update.
Corresponds to the JSON property excludes
2514 2515 2516 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2514 def excludes @excludes end |
#exclusive_patches ⇒ Array<String>
An exclusive list of kbs to be updated. These are the only patches that will
be updated. This field must not be used with other patch configurations.
Corresponds to the JSON property exclusivePatches
2520 2521 2522 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2520 def exclusive_patches @exclusive_patches end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2527 2528 2529 2530 2531 |
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2527 def update!(**args) @classifications = args[:classifications] if args.key?(:classifications) @excludes = args[:excludes] if args.key?(:excludes) @exclusive_patches = args[:exclusive_patches] if args.key?(:exclusive_patches) end |