Class: Google::Apis::OsconfigV1beta::WindowsUpdateSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/osconfig_v1beta/classes.rb,
lib/google/apis/osconfig_v1beta/representations.rb,
lib/google/apis/osconfig_v1beta/representations.rb

Overview

Windows patching is performed using the Windows Update Agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WindowsUpdateSettings

Returns a new instance of WindowsUpdateSettings.



2699
2700
2701
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2699

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classificationsArray<String>

Only apply updates of these windows update classifications. If empty, all updates are applied. Corresponds to the JSON property classifications

Returns:

  • (Array<String>)


2686
2687
2688
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2686

def classifications
  @classifications
end

#excludesArray<String>

List of KBs to exclude from update. Corresponds to the JSON property excludes

Returns:

  • (Array<String>)


2691
2692
2693
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2691

def excludes
  @excludes
end

#exclusive_patchesArray<String>

An exclusive list of kbs to be updated. These are the only patches that will be updated. This field must not be used with other patch configurations. Corresponds to the JSON property exclusivePatches

Returns:

  • (Array<String>)


2697
2698
2699
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2697

def exclusive_patches
  @exclusive_patches
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2704
2705
2706
2707
2708
# File 'lib/google/apis/osconfig_v1beta/classes.rb', line 2704

def update!(**args)
  @classifications = args[:classifications] if args.key?(:classifications)
  @excludes = args[:excludes] if args.key?(:excludes)
  @exclusive_patches = args[:exclusive_patches] if args.key?(:exclusive_patches)
end